@@ -87,8 +87,8 @@ extern int yydebug;
     Xstring = 39,
     Xcomment = 40,
     Xarg = 41,
-    XDotPS = 42,
-    XDotPE = 43,
+    DotPS = 42,
+    DotPE = 43,
     Xht = 44,
     Xwid = 45,
     Xrad = 46,
@@ -113,8 +113,8 @@ extern int yydebug;
     Xnth = 65,
     Xlast = 66,
     Xfill = 67,
-    XDotx = 68,
-    XDoty = 69,
+    Dotx = 68,
+    Doty = 69,
     Xprint = 70,
     Xcopy = 71,
     Xreset = 72,
@@ -131,17 +131,17 @@ extern int yydebug;
     Xendfor = 83,
     Xsprintf = 84,
     Xcorner = 85,
-    XDotne = 86,
-    XDotse = 87,
-    XDotnw = 88,
-    XDotsw = 89,
-    XDotn = 90,
-    XDots = 91,
-    XDote = 92,
-    XDotw = 93,
-    XDotstart = 94,
-    XDotend = 95,
-    XDotc = 96,
+    Dotne = 86,
+    Dotse = 87,
+    Dotnw = 88,
+    Dotsw = 89,
+    Dotn = 90,
+    Dots = 91,
+    Dote = 92,
+    Dotw = 93,
+    Dotstart = 94,
+    Dotend = 95,
+    Dotc = 96,
     Xcompare = 97,
     Xeqeq = 98,
     Xneq = 99,
