@@ -40,8 +40,8 @@
 #define	Xstring	39
 #define	Xcomment	40
 #define	Xarg	41
-#define	XDotPS	42
-#define	XDotPE	43
+#define	DotPS	42
+#define	DotPE	43
 #define	Xht	44
 #define	Xwid	45
 #define	Xrad	46
@@ -66,8 +66,8 @@
 #define	Xnth	65
 #define	Xlast	66
 #define	Xfill	67
-#define	XDotx	68
-#define	XDoty	69
+#define	Dotx	68
+#define	Doty	69
 #define	Xprint	70
 #define	Xcopy	71
 #define	Xreset	72
@@ -84,17 +84,17 @@
 #define	Xendfor	83
 #define	Xsprintf	84
 #define	Xcorner	85
-#define	XDotne	86
-#define	XDotse	87
-#define	XDotnw	88
-#define	XDotsw	89
-#define	XDotn	90
-#define	XDots	91
-#define	XDote	92
-#define	XDotw	93
-#define	XDotstart	94
-#define	XDotend	95
-#define	XDotc	96
+#define	Dotne	86
+#define	Dotse	87
+#define	Dotnw	88
+#define	Dotsw	89
+#define	Dotn	90
+#define	Dots	91
+#define	Dote	92
+#define	Dotw	93
+#define	Dotstart	94
+#define	Dotend	95
+#define	Dotc	96
 #define	Xcompare	97
 #define	Xeqeq	98
 #define	Xneq	99
